GitHubIssueTracker class

IssueTracker implementation for GitHub.

Inheritance

Constructors

GitHubIssueTracker({required String organization, required String repository, String? template, Map<String, String>? customParameters})

Properties

customParameters → Map<String, String>
Custom parameters to be added to the issue tracker's URI.
finalinherited
endpoint → String
The endpoint of the issue tracker that'll be appended to the website (e.g. 'werainkhatri/issue/issues/new').
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
organization → String
GitHub organization / user name, eg: 'flutter' / 'werainkhatri'.
final
repository → String
GitHub repository name, eg: 'flutter' / 'issue'.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
template → String?
The name of the template file to use when creating a the issue.
final
website → String
The authority url of the issue tracking website (e.g. `'github.com'``).
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited