IssueConfig class

Constructors

IssueConfig({required IssueTemplate template, required IssueTracker tracker, String issueFileName = kIssueFile})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
issueFileName → String
The name of the file that will be used as prompt to get user input.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
template → IssueTemplate
The issue template that will be used to build the issue.
final
tracker → IssueTracker
The issue tracker where the user will be directed once the issue is built.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited